@@ -577,10 +577,10 @@ class L1A_object(GMS_object):
         # if re.search(r'ETM+', self.sensor) and self.acq_datetime > datetime.datetime(year=2003, month=5, day=31,
         #                                                                             tzinfo=datetime.timezone.utc):
         if is_dataset_provided_as_fullScene(self.GMS_identifier):
-            self.trueDataCornerPos = calc_FullDataset_corner_positions(self.mask_nodata, algorithm='numpy',
-                                                                       assert_four_corners=True)
+            kw = dict(algorithm='numpy', assert_four_corners=True)
         else:
-            self.trueDataCornerPos = calc_FullDataset_corner_positions(self.mask_nodata, assert_four_corners=False)
+            kw = dict(algorithm='shapely', assert_four_corners=False)
+        self.trueDataCornerPos = calc_FullDataset_corner_positions(self.mask_nodata, **kw)
 
         # set true data corner positions (lon/lat coordinates)
         trueCorPosXY = [tuple(reversed(i)) for i in self.trueDataCornerPos]
