@@ -59,6 +59,7 @@ from ..misc import database_tools as DB_T
 from ..misc import helper_functions as HLP_F
 from ..misc import path_generator as PG
 from ..misc.logging import GMS_logger, close_logger
+from ..misc.locks import DatabaseLock
 from ..misc.spatial_index_mediator import SpatialIndexMediator
 from ..misc.definition_dicts import get_GMS_sensorcode, get_outFillZeroSaturated
 
@@ -130,14 +131,15 @@ class Scene_finder(object):
         """
         SpIM = SpatialIndexMediator(host=CFG.spatial_index_server_host, port=CFG.spatial_index_server_port,
                                     timeout=timeout, retries=10)
-        self.possib_ref_scenes = SpIM.getFullSceneDataForDataset(envelope=self.boundsLonLat,
-                                                                 timeStart=self.timeStart,
-                                                                 timeEnd=self.timeEnd,
-                                                                 minCloudCover=self.min_cloudcov,
-                                                                 maxCloudCover=self.max_cloudcov,
-                                                                 datasetid=CFG.datasetid_spatial_ref,
-                                                                 refDate=self.src_AcqDate,
-                                                                 maxDaysDelta=self.plusminus_days)
+        with DatabaseLock(allowed_slots=1, logger=self.logger):
+            self.possib_ref_scenes = SpIM.getFullSceneDataForDataset(envelope=self.boundsLonLat,
+                                                                     timeStart=self.timeStart,
+                                                                     timeEnd=self.timeEnd,
+                                                                     minCloudCover=self.min_cloudcov,
+                                                                     maxCloudCover=self.max_cloudcov,
+                                                                     datasetid=CFG.datasetid_spatial_ref,
+                                                                     refDate=self.src_AcqDate,
+                                                                     maxDaysDelta=self.plusminus_days)
 
         if self.possib_ref_scenes:
             # fill GeoDataFrame with possible ref scene parameters
