@@ -889,7 +889,7 @@ class AtmCorr(object):
 
         self.ac_input = dict(
             rs_image=rs_image,
-            options=self.options,  # type: dict
+            options=self.options,  # dict
             logger=repr(self.logger),  # only a string
             script=script
         )
@@ -915,6 +915,7 @@ class AtmCorr(object):
             if dump_ac_input:
                 path_dump = self.inObjs[0].pathGen.get_path_ac_input_dump()
                 with open(path_dump, 'wb') as outF:
+                    self.ac_input['rs_image'].logger = None
                     dill.dump(self.ac_input, outF)
 
                 self.logger.error('An error occurred during atmospheric correction. Inputs have been dumped to %s.'
@@ -928,7 +929,8 @@ class AtmCorr(object):
 
         finally:
             # rs_image.logger must be closed properly in any case
-            rs_image.logger.close()
+            if rs_image.logger is not None:
+                rs_image.logger.close()
 
         # get processing infos
         self.proc_info = self.ac_input['options']['processing']
