@@ -59,6 +59,7 @@ from ..misc.logging import GMS_logger, close_logger
 from ..misc.database_tools import get_overlapping_scenes_from_postgreSQLdb
 from ..misc.path_generator import path_generator
 from ..misc.spatial_index_mediator import SpatialIndexMediator
+from ..misc.locks import DatabaseLock
 
 if TYPE_CHECKING:
     from ..model.gms_object import GMS_identifier  # noqa F401  # flake8 issue
@@ -377,11 +378,12 @@ class DEM_Creator(object):
         if use_index_mediator:
             SpIM = SpatialIndexMediator(host=CFG.spatial_index_server_host, port=CFG.spatial_index_server_port,
                                         timeout=timeout_sec, retries=10)
-            scenes = SpIM.getFullSceneDataForDataset(envelope=corner_coord_to_minmax(tgt_corner_coord_lonlat),
-                                                     timeStart=datetime(1970, 1, 1, 0, 0, 0),
-                                                     timeEnd=datetime(2100, 12, 31, 0, 0, 0),
-                                                     minCloudCover=0, maxCloudCover=100,
-                                                     datasetid=self.dsID_dic[self.dem_sensor])
+            with DatabaseLock(allowed_slots=1, logger=self.logger):
+                scenes = SpIM.getFullSceneDataForDataset(envelope=corner_coord_to_minmax(tgt_corner_coord_lonlat),
+                                                         timeStart=datetime(1970, 1, 1, 0, 0, 0),
+                                                         timeEnd=datetime(2100, 12, 31, 0, 0, 0),
+                                                         minCloudCover=0, maxCloudCover=100,
+                                                         datasetid=self.dsID_dic[self.dem_sensor])
             sceneIDs_srtm = [scene.sceneid for scene in scenes]
 
         else:
@@ -406,12 +408,19 @@ class DEM_Creator(object):
         # get overlapping SRTM scene IDs from GMS database
         try:
             # try to use the SpatialIndexMediator
+            # noinspection PyBroadException
             try:
                 sceneIDs_srtm = self.get_overlapping_DEM_tiles(tgt_corner_coord_lonlat, timeout_sec)
             except ConnectionRefusedError:
                 # fallback to plain pgSQL
                 self.logger.warning('SpatialIndexMediator refused connection. Falling back to plain postgreSQL query.')
                 sceneIDs_srtm = self.get_overlapping_DEM_tiles(tgt_corner_coord_lonlat, use_index_mediator=False)
+            except Exception as err:
+                # fallback to plain pgSQL
+                self.logger.warning('Error while running SpatialIndexMediator database query. '
+                                    'Falling back to plain postgreSQL query. '
+                                    'Error message was: %s' % str(repr(err)))
+                sceneIDs_srtm = self.get_overlapping_DEM_tiles(tgt_corner_coord_lonlat, use_index_mediator=False)
 
             if not sceneIDs_srtm:
                 # fallback to plain pgSQL
