@@ -328,10 +328,10 @@ def get_path_ac_options(GMS_id):
 
     ac_options_file_dic = {
         'AVNIR-2': None,
-        'TM4': 'sicor_l8_user_options.json',
-        'TM5': 'sicor_l8_user_options.json',
-        'TM7': 'sicor_l8_user_options.json',  # AC uses Landsat-8 options for L7 but reads only a subset of the options
-        'LDCM': 'sicor_l8_user_options.json',
+        'TM4': 'l8_options.json',
+        'TM5': 'l8_options.json',
+        'TM7': 'l8_options.json',  # AC uses Landsat-8 options for L7 but reads only a subset of the options
+        'LDCM': 'l8_options.json',
         'SPOT1a': None,
         'SPOT1b': None,
         'SPOT2a': None,
@@ -344,8 +344,8 @@ def get_path_ac_options(GMS_id):
         'SPOT5b': None,
         'RE5': None,
         'AST_full': None,
-        'S2A_full': 'sicor_s2_user_options.json',
-        'S2B_full': 'sicor_s2_user_options.json',
+        'S2A_full': 's2_options.json',
+        'S2B_full': 's2_options.json',
     }
 
     try:
