@@ -33,7 +33,8 @@ import builtins
 import re
 import psycopg2
 import psycopg2.extras
-from collections import OrderedDict, Mapping
+from collections import OrderedDict
+from collections.abc import Mapping
 import multiprocessing
 from inspect import getargvalues, stack, signature, _empty
 import json
@@ -85,8 +86,8 @@ def set_config(job_ID, json_config='', reset_status=False, **kwargs):
     :param json_config:     path to JSON file containing configuration parameters or a string in JSON format
     :param reset_status:    whether to reset the job status or not (default=False)
     :param kwargs:          keyword arguments to be passed to JobConfig
-
-    NOTE: All keyword arguments given here WILL OVERRIDE configurations that have been previously set via WebUI!
+                            NOTE: All keyword arguments given here WILL OVERRIDE configurations that have been
+                                  previously set via WebUI or via the json_config parameter!
 
     :Keyword Arguments:
         - inmem_serialization:     False: write intermediate results to disk in order to save memory
@@ -242,6 +243,7 @@ class JobConfig(object):
         self.disable_exception_handler = gp('disable_exception_handler')
         self.disable_IO_locks = gp('disable_IO_locks')
         self.disable_CPU_locks = gp('disable_CPU_locks')
+        self.disable_DB_locks = gp('disable_DB_locks')
         self.disable_memory_locks = gp('disable_memory_locks')
         self.min_version_mem_usage_stats = gp('min_version_mem_usage_stats')
         self.log_level = gp('log_level')
@@ -278,7 +280,7 @@ class JobConfig(object):
             self.path_archive = gp('path_archive', fallback=get_dbpath('foldername_download'))
             self.path_procdata_scenes = gp('path_procdata_scenes', fallback=get_dbpath('foldername_procdata_scenes'))
             self.path_procdata_MGRS = gp('path_procdata_MGRS', fallback=get_dbpath('foldername_procdata_MGRS'))
-            self.path_ECMWF_db = self.absP(self.DB_config_table['path_ECMWF_db'])
+            self.path_ECMWF_db = gp('path_ECMWF_db', fallback=self.absP(self.DB_config_table['path_ECMWF_db']))
             self.path_benchmarks = gp('path_benchmarks', fallback=self.absP(self.DB_config_table['path_benchmarks']))
             self.path_job_logs = gp('path_job_logs', fallback=get_dbpath('foldername_job_logs'))
 
