@@ -45,6 +45,7 @@ gms_schema_input = dict(
             disable_exception_handler=dict(type='boolean', required=False),
             disable_IO_locks=dict(type='boolean', required=False),
             disable_CPU_locks=dict(type='boolean', required=False),
+            disable_DB_locks=dict(type='boolean', required=False),
             disable_memory_locks=dict(type='boolean', required=False),
             min_version_mem_usage_stats=dict(type='string', required=False),
             log_level=dict(type='string', required=False, allowed=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']),
@@ -215,6 +216,7 @@ parameter_mapping = dict(
     disable_exception_handler=('global_opts', 'disable_exception_handler'),
     disable_IO_locks=('global_opts', 'disable_IO_locks'),
     disable_CPU_locks=('global_opts', 'disable_CPU_locks'),
+    disable_DB_locks=('global_opts', 'disable_DB_locks'),
     disable_memory_locks=('global_opts', 'disable_memory_locks'),
     min_version_mem_usage_stats=('global_opts', 'min_version_mem_usage_stats'),
     log_level=('global_opts', 'log_level'),
