@@ -77,7 +77,7 @@ def L1A_map(dataset_dict):  # map (scene-wise parallelization)
 @EXC_H.log_uncaught_exceptions
 @update_proc_status
 def L1A_map_1(dataset_dict, block_size=None):  # map (scene-wise parallelization)
-    # type: (dict) -> List[L1A_P.L1A_object]
+    # type: (dict, tuple) -> List[L1A_P.L1A_object]
 
     L1A_obj = L1A_P.L1A_object(**dataset_dict)
     L1A_obj.block_at_system_overload(max_usage=CFG.critical_mem_usage)
@@ -87,8 +87,10 @@ def L1A_map_1(dataset_dict, block_size=None):  # map (scene-wise parallelization
     L1A_obj.apply_nodata_mask_to_ObjAttr('arr')  # nodata mask is automatically calculated
     L1A_obj.add_rasterInfo_to_MetaObj()
     L1A_obj.reference_data('UTM')
-    tiles = list(L1A_obj.to_tiles(
-        block_size if block_size else CFG.tiling_block_size_XY))  # cut (block-wise parallelization)
+    tiles = [tile for tile in
+             # cut (block-wise parallelization)
+             L1A_obj.to_tiles(blocksize=block_size if block_size else CFG.tiling_block_size_XY)
+             if tile is not None]    # None is returned in case the tile contains no data at all
     return tiles
 
 
@@ -182,7 +184,7 @@ def L1C_map(L1B_objs):
 @EXC_H.log_uncaught_exceptions
 @update_proc_status
 def L2A_map(L1C_objs, block_size=None, return_tiles=True):
-    # type: (Union[List[L1C_P.L1C_object], Tuple[L1C_P.L1C_object]]) -> Union[List[L2A_P.L2A_object], L2A_P.L2A_object]
+    # type: (Union[List[L1C_P.L1C_object], Tuple[L1C_P.L1C_object]], tuple, bool) -> Union[List[L2A_P.L2A_object], L2A_P.L2A_object]  # noqa
     """Geometric homogenization.
 
     Performs correction of geometric displacements, resampling to target grid of the usecase and merges multiple
@@ -229,6 +231,7 @@ def L2A_map(L1C_objs, block_size=None, return_tiles=True):
 
     if return_tiles:
         L2A_tiles = list(L2A_obj.to_tiles(blocksize=block_size if block_size else CFG.tiling_block_size_XY))
+        L2A_tiles = [i for i in L2A_tiles if i is not None]  # None is returned in case the tile contains no data at all
         [L2A_tile.record_mem_usage() for L2A_tile in L2A_tiles]
         return L2A_tiles
     else:
