@@ -216,13 +216,15 @@ class ProcessController(object):
                 if os.path.isfile(assumed_path_GMS_file):
                     GMS_file_dict = INP_R.GMSfile2dict(assumed_path_GMS_file)
                     target_LayerBandsAssignment = \
-                        get_LayerBandsAssignment(GMS_identifier(
-                            image_type=dataset['image_type'],
-                            satellite=dataset['satellite'],
-                            sensor=dataset['sensor'],
-                            subsystem=dataset['subsystem'] if path_logfile != path_logfile_merged_ss else '',
-                            proc_level=ProcL,  # must be respected because LBA changes after atm. Corr.
-                            dataset_ID=dataset['dataset_ID']), nBands=(1 if dataset['sensormode'] == 'P' else None))
+                        get_LayerBandsAssignment(
+                            GMS_identifier(
+                                image_type=dataset['image_type'],
+                                satellite=dataset['satellite'],
+                                sensor=dataset['sensor'],
+                                subsystem=dataset['subsystem'] if path_logfile != path_logfile_merged_ss else '',
+                                proc_level=ProcL,  # must be respected because LBA changes after atm. Corr.
+                                dataset_ID=dataset['dataset_ID']),
+                            nBands=(1 if dataset['sensormode'] == 'P' else None))
 
                     # check if the LayerBandsAssignment of the written dataset on disk equals the
                     # desired LayerBandsAssignment
